@@ -12,7 +12,7 @@ set.seed(1)
 simdata <- simulate_gaussian(N = 200, weights = c(1, 2, 3))
 
 glmModel <- glm(Y ~ X1 + X2 + X3, data = simdata, family = gaussian(link = "identity"))
-summary(glmModel)
+summary(glmModel)$coefficients
 
 rm(glmModel)
 
@@ -26,8 +26,8 @@ simdata <- simulate_gaussian(link = "identity")
 linearModel <- lm(Y ~ X1 + X2 + X3, data = simdata)
 glmModel <- glm(Y ~ X1 + X2 + X3, data = simdata, family = gaussian(link = "identity"))
 
-summary(linearModel)
-summary(glmModel)
+summary(linearModel)$coefficients
+summary(glmModel)$coefficients
 
 rm(simdata, linearModel, glmModel)
 
