@@ -49,10 +49,9 @@ test_that("All links execute", {
   expect_true(all(class(simulate_binomial(link = "cauchit")) == c("tbl_df", "tbl", "data.frame")))
   expect_true(all(class(simulate_binomial(link = "log", weights = -.01)) == c("tbl_df", "tbl", "data.frame")))
   expect_true(all(class(simulate_binomial(link = "cloglog", weights = .1)) == c("tbl_df", "tbl", "data.frame")))
-})
-
-test_that("Ancillary parameter function works if ancillary is provided", {
-  expect_true(simulate_binomial(ancillary = 10) %>% nrow() > 0)
+  expect_true(all(class(simulate_binomial(link = "loglog", weights = .1)) == c("tbl_df", "tbl", "data.frame")))
+  expect_true(all(class(simulate_binomial(link = "logc", weights = -.1)) == c("tbl_df", "tbl", "data.frame")))
+  expect_true(all(class(simulate_binomial(link = "identity", weights = .1)) == c("tbl_df", "tbl", "data.frame")))
 })
 
 ###############################################
@@ -65,6 +64,4 @@ test_that("Confirm input checing works.", {
   expect_error(simulate_binomial(weights = c()), NULL)
   expect_error(simulate_binomial(unrelated = -1), NULL)
   expect_error(simulate_binomial(unrelated = c(10, 20)), NULL)
-  expect_error(simulate_binomial(ancillary = -1), NULL)
-  expect_error(simulate_binomial(ancillary = c(10, 20)), NULL)
 })
