@@ -48,10 +48,6 @@ test_that("All links execute", {
   expect_true(all(class(simulate_poisson(link = "sqrt")) == c("tbl_df", "tbl", "data.frame")))
 })
 
-test_that("Ancillary parameter function works if ancillary is provided", {
-  expect_true(simulate_poisson(ancillary = 10) %>% nrow() > 0)
-})
-
 ###############################################
 # Input checking
 ###############################################
@@ -62,6 +58,4 @@ test_that("Confirm input checing works.", {
   expect_error(simulate_poisson(weights = c()), NULL)
   expect_error(simulate_poisson(unrelated = -1), NULL)
   expect_error(simulate_poisson(unrelated = c(10, 20)), NULL)
-  expect_error(simulate_poisson(ancillary = -1), NULL)
-  expect_error(simulate_poisson(ancillary = c(10, 20)), NULL)
 })
